@@ -118,6 +118,8 @@ Julia::Julia():color_shift(angle::degrees(0))
 
 	bailout=4;
 	lp=log(log(bailout));
+	Layer::Vocab voc(get_param_vocab());
+	Layer::fill_static(voc);
 }
 
 bool
@@ -144,6 +146,7 @@ Julia::set_param(const String & param, const ValueBase &value)
 	IMPORT(smooth_outside);
 	IMPORT(broken);
 
+// TODO: Use IMPORT_PLUS
 	if(param=="iterations" && value.same_type_as(iterations))
 	{
 		iterations=value.get(iterations);
@@ -151,6 +154,7 @@ Julia::set_param(const String & param, const ValueBase &value)
 			iterations=0;
 		if(iterations>500000)
 			iterations=500000;
+		set_param_static(param, value.get_static());
 		return true;
 	}
 	if(param=="bailout" && value.same_type_as(bailout))
@@ -158,6 +162,7 @@ Julia::set_param(const String & param, const ValueBase &value)
 		bailout=value.get(bailout);
 		bailout*=bailout;
 		lp=log(log(bailout));
+		set_param_static(param, value.get_static());
 		return true;
 	}
 
@@ -188,7 +193,11 @@ Julia::get_param(const String & param)const
 	EXPORT(broken);
 
 	if(param=="bailout")
-		return sqrt(bailout);
+	{
+		ValueBase ret(sqrt(bailout));
+		ret.set_static(get_param_static(param));
+		return ret;
+	}
 
 	EXPORT_NAME();
 	EXPORT_VERSION();
