@@ -69,6 +69,8 @@ Rotate::Rotate():
 	sin_val	(0),
 	cos_val	(1)
 {
+	Layer::Vocab voc(get_param_vocab());
+	Layer::fill_static(voc);
 }
 
 Rotate::~Rotate()
@@ -85,6 +87,7 @@ Rotate::set_param(const String & param, const ValueBase &value)
 		amount=value.get(amount);
 		sin_val=Angle::sin(amount).get();
 		cos_val=Angle::cos(amount).get();
+		set_param_static(param, value.get_static());
 		return true;
 	}
 
@@ -253,6 +256,11 @@ Rotate::accelerated_render(Context context,Surface *surface,int quality, const R
 
 	Surface::pen pen(surface->begin());
 
+	// There is not need to supersample when the rotation is 90 or -90
+	// There is a one to one pixel correspondence.
+	if(amount.dist(Angle::deg(90))== Angle::deg(0.0) || amount.dist(Angle::deg(-90))== Angle::deg(0.0))
+		quality = 7;
+
 	if(quality<=4)
 	{
 		// CUBIC
