@@ -7,6 +7,7 @@
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2011 Carlos López
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -23,8 +24,6 @@
 
 /* === H E A D E R S ======================================================= */
 
-#define SYNFIG_NO_ANGLE
-
 #ifdef USING_PCH
 #	include "pch.h"
 #else
@@ -70,6 +69,8 @@ Layer_Stretch::Layer_Stretch():
 	amount(1,1),
 	center(0,0)
 {
+	Layer::Vocab voc(get_param_vocab());
+	Layer::fill_static(voc);
 }
 
 
@@ -102,10 +103,12 @@ Layer_Stretch::get_param_vocab()const
 	ret.push_back(ParamDesc("amount")
 		.set_local_name(_("Amount"))
 		.set_origin("center")
+		.set_description(_("Size of the stretch relative to its Center"))
 	);
 
 	ret.push_back(ParamDesc("center")
 		.set_local_name(_("Center"))
+		.set_description(_("Where the stretch distortion is centered"))
 	);
 
 	return ret;
