@@ -6,6 +6,7 @@
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2011 Carlos López
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -65,14 +66,23 @@ SuperSample::SuperSample():width(2),height(2)
 {
 	scanline=false;
 	alpha_aware=true;
+	Layer::Vocab voc(get_param_vocab());
+	Layer::fill_static(voc);
 }
 
 bool
 SuperSample::set_param(const String & param, const ValueBase &value)
 {
-
-	IMPORT(width);
-	IMPORT(height);
+	IMPORT_PLUS(width,
+		if(value.get(int()) < 1) width = 1;
+		else width=value.get(int());
+		return true;
+		)
+	IMPORT_PLUS(height,
+		if(value.get(int()) < 1) height = 1;
+		else height=value.get(int());
+		return true;
+		)
 	IMPORT(scanline);
 	IMPORT(alpha_aware);
 
@@ -225,6 +235,7 @@ SuperSample::get_param_vocab(void)const
 	);
 	ret.push_back(ParamDesc("alpha_aware")
 		.set_local_name(_("Be Alpha Safe"))
+		.set_description(_("Avoid alpha artifacts when checked"))
 	);
 
 	return ret;
