@@ -6,6 +6,7 @@
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2011 Carlos López
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -71,6 +72,8 @@ Twirl::Twirl():
 	distort_inside(true),
 	distort_outside(false)
 {
+	Layer::Vocab voc(get_param_vocab());
+	Layer::fill_static(voc);
 }
 
 bool
@@ -107,6 +110,7 @@ Twirl::get_param_vocab()const
 
 	ret.push_back(ParamDesc("center")
 		.set_local_name(_("Center"))
+		.set_description(_("Center of the circle"))
 	);
 
 	ret.push_back(ParamDesc("radius")
@@ -118,15 +122,18 @@ Twirl::get_param_vocab()const
 
 	ret.push_back(ParamDesc("rotations")
 		.set_local_name(_("Rotations"))
+		.set_description(_("The number of rotations of the twirl effect"))
 		.set_origin("center")
 	);
 
 	ret.push_back(ParamDesc("distort_inside")
 		.set_local_name(_("Distort Inside"))
+		.set_description(_("When checked, distorts inside the circle"))
 	);
 
 	ret.push_back(ParamDesc("distort_outside")
 		.set_local_name(_("Distort Outside"))
+		.set_description(_("When checked, distorts outside the circle"))
 	);
 
 	return ret;
