@@ -7,6 +7,7 @@
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007-2008 Chris Moore
+**	Copyright (c) 2011 Carlos López
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -61,10 +62,12 @@ SYNFIG_LAYER_SET_CVS_ID(XORPattern,"$Id$");
 /* === M E T H O D S ======================================================= */
 
 XORPattern::XORPattern():
-	Layer_Composite	(1.0,Color::BLEND_STRAIGHT),
+	Layer_Composite(1.0,Color::BLEND_COMPOSITE),
 	origin(0.125,0.125),
 	size(0.25,0.25)
 {
+	Layer::Vocab voc(get_param_vocab());
+	Layer::fill_static(voc);
 }
 
 bool
@@ -120,9 +123,11 @@ XORPattern::get_param_vocab()const
 
 	ret.push_back(ParamDesc("origin")
 		.set_local_name(_("Origin"))
+		.set_description(_("Center of the pattern"))
 	);
 	ret.push_back(ParamDesc("size")
 		.set_local_name(_("Size"))
+		.set_description(_("Size of the pattern"))
 		.set_origin("origin")
 	);
 
