@@ -78,10 +78,13 @@ inline void clamp(synfig::Vector &v)
 }
 
 Blur_Layer::Blur_Layer():
-	Layer_Composite	(1.0,Color::BLEND_STRAIGHT),
+	Layer_Composite(1.0,Color::BLEND_STRAIGHT),
 	size(0.1,0.1),
 	type(Blur::FASTGAUSSIAN)
 {
+	Layer::Vocab voc(get_param_vocab());
+	Layer::fill_static(voc);
+	set_param_static("blend_method", true);
 }
 
 bool
