@@ -7,6 +7,7 @@
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007, 2008 Chris Moore
+**	Copyright (c) 2011 Carlos López
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -64,13 +65,13 @@ SYNFIG_LAYER_SET_CVS_ID(CheckerBoard,"$Id$");
 /* === M E T H O D S ======================================================= */
 
 CheckerBoard::CheckerBoard():
-	Layer_Composite	(1.0,Color::BLEND_STRAIGHT),
+	Layer_Composite	(1.0,Color::BLEND_COMPOSITE),
 	color			(Color::black()),
 	origin			(Point(0.125,0.125)),
 	size			(Point(0.25,0.25))
 {
-
-	set_blend_method(Color::BLEND_STRAIGHT);
+	Layer::Vocab voc(get_param_vocab());
+	Layer::fill_static(voc);
 }
 
 inline bool
@@ -123,6 +124,7 @@ CheckerBoard::get_param_vocab()const
 	);
 	ret.push_back(ParamDesc("origin")
 		.set_local_name(_("Origin"))
+		.set_description(_("Center of the checkers"))
 	);
 	ret.push_back(ParamDesc("size")
 		.set_local_name(_("Size"))
