@@ -7,6 +7,7 @@
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2008 Chris Moore
+**	Copyright (c) 2011 Carlos López
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -60,7 +61,7 @@ SYNFIG_LAYER_SET_CVS_ID(Circle,"$Id$");
 /* -- F U N C T I O N S ----------------------------------------------------- */
 
 Circle::Circle():
-	Layer_Composite	(1.0,Color::BLEND_STRAIGHT),
+	Layer_Composite	(1.0,Color::BLEND_COMPOSITE),
 	color			(Color::black()),
 	origin			(0,0),
 	radius			(1),
@@ -69,6 +70,8 @@ Circle::Circle():
 	falloff			(FALLOFF_INTERPOLATION_LINEAR)
 {
 	constructcache();
+	Layer::Vocab voc(get_param_vocab());
+	Layer::fill_static(voc);
 }
 
 bool
@@ -123,18 +126,22 @@ Circle::get_param_vocab()const
 
 	ret.push_back(ParamDesc("color")
 		.set_local_name(_("Color"))
+		.set_description(_("Fill color of the layer"))
 	);
 	ret.push_back(ParamDesc("radius")
 		.set_local_name(_("Radius"))
 		.set_origin("origin")
+		.set_description(_("Radius of the circle"))
 		.set_is_distance()
 	);
 	ret.push_back(ParamDesc("feather")
 		.set_local_name(_("Feather"))
 		.set_is_distance()
+		.set_description(_("Amount of feather of the circle"))
 	);
 	ret.push_back(ParamDesc("origin")
 		.set_local_name(_("Origin"))
+		.set_description(_("Center of the circle"))
 	);
 	ret.push_back(ParamDesc("invert")
 		.set_local_name(_("Invert"))
