@@ -7,6 +7,7 @@
 **	\legal
 **	Copyright (c) 2002 Robert B. Quattlebaum Jr.
 **	Copyright (c) 2007, 2008 Chris Moore
+**	Copyright (c) 2011 Carlos López
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -75,13 +76,15 @@ inline int floor_to_int(const double x) { return static_cast<int>(floor(x)); }
 /* === E N T R Y P O I N T ================================================= */
 
 Rectangle::Rectangle():
-	Layer_Composite(1.0,Color::BLEND_STRAIGHT),
+	Layer_Composite(1.0,Color::BLEND_COMPOSITE),
 	color(Color::black()),
 	point1(0,0),
 	point2(1,1),
 	expand(0),
 	invert(false)
 {
+	Layer::Vocab voc(get_param_vocab());
+	Layer::fill_static(voc);
 }
 
 bool
@@ -120,15 +123,18 @@ Rectangle::get_param_vocab()const
 
 	ret.push_back(ParamDesc("color")
 		.set_local_name(_("Color"))
+		.set_description(_("Fill color of the layer"))
 	);
 
 	ret.push_back(ParamDesc("point1")
 		.set_local_name(_("Point 1"))
 		.set_box("point2")
+		.set_description(_("First corner of the rectangle"))
 	);
 
 	ret.push_back(ParamDesc("point2")
 		.set_local_name(_("Point 2"))
+		.set_description(_("Second corner of the rectangle"))
 	);
 
 	ret.push_back(ParamDesc("expand")
