@@ -6,6 +6,7 @@
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2011 Carlos López
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -65,12 +66,14 @@ SYNFIG_LAYER_SET_CVS_ID(ConicalGradient,"$Id$");
 /* === E N T R Y P O I N T ================================================= */
 
 ConicalGradient::ConicalGradient():
-	Layer_Composite(1.0,Color::BLEND_STRAIGHT),
+	Layer_Composite(1.0,Color::BLEND_COMPOSITE),
 	gradient(Color::black(),Color::white()),
 	center(0,0),
 	angle(Angle::zero()),
 	symmetric(false)
 {
+	Layer::Vocab voc(get_param_vocab());
+	Layer::fill_static(voc);
 }
 
 bool
@@ -104,19 +107,23 @@ ConicalGradient::get_param_vocab()const
 
 	ret.push_back(ParamDesc("gradient")
 		.set_local_name(_("Gradient"))
+		.set_description(_("Gradient to apply"))
 	);
 
 	ret.push_back(ParamDesc("center")
 		.set_local_name(_("Center"))
+		.set_description(_("Center of the cone"))
 	);
 
 	ret.push_back(ParamDesc("angle")
 		.set_local_name(_("Angle"))
 		.set_origin("center")
+		.set_description(_("Rotation of the gradient around the center"))
 	);
 
 	ret.push_back(ParamDesc("symmetric")
 		.set_local_name(_("Symmetric"))
+		.set_description(_("When checked the gradient is looped"))
 	);
 
 	return ret;
