@@ -7,6 +7,7 @@
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007-2008 Chris Moore
+**	Copyright (c) 2011 Carlos López
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -205,6 +206,7 @@ CurveGradient::sync()
 
 
 CurveGradient::CurveGradient():
+	Layer_Composite(1.0,Color::BLEND_COMPOSITE),
 	origin(0,0),
 	width(0.25),
 	gradient(Color::black(), Color::white()),
@@ -228,6 +230,8 @@ CurveGradient::CurveGradient():
 	bline_loop=true;
 
 	sync();
+	Layer::Vocab voc(get_param_vocab());
+	Layer::fill_static(voc);
 }
 
 inline Color
@@ -530,28 +534,39 @@ CurveGradient::get_param_vocab()const
 	Layer::Vocab ret(Layer_Composite::get_param_vocab());
 
 	ret.push_back(ParamDesc("origin")
-				  .set_local_name(_("Origin")));
-
+				  .set_local_name(_("Origin"))
+				  .set_description(_("Offset for the Vertices List"))
+	);
 	ret.push_back(ParamDesc("width")
 				  .set_is_distance()
-				  .set_local_name(_("Width")));
-
+				  .set_local_name(_("Width"))
+				  .set_description(_("Global width of the gradient"))
+	);
 	ret.push_back(ParamDesc("bline")
 				  .set_local_name(_("Vertices"))
 				  .set_origin("origin")
 				  .set_hint("width")
-				  .set_description(_("A list of BLine Points")));
-
+				  .set_description(_("A list of BLine Points"))
+	);
 	ret.push_back(ParamDesc("gradient")
-				  .set_local_name(_("Gradient")));
+				  .set_local_name(_("Gradient"))
+				  .set_description(_("Gradient to apply"))
+	);
 	ret.push_back(ParamDesc("loop")
-				  .set_local_name(_("Loop")));
+				  .set_local_name(_("Loop"))
+				  .set_description(_("When checked the gradient is looped"))
+	);
 	ret.push_back(ParamDesc("zigzag")
-				  .set_local_name(_("ZigZag")));
+				  .set_local_name(_("ZigZag"))
+				  .set_description(_("When checked the gradient is summetrical at the center"))
+	);
 	ret.push_back(ParamDesc("perpendicular")
-				  .set_local_name(_("Perpendicular")));
+				  .set_local_name(_("Perpendicular"))
+	);
 	ret.push_back(ParamDesc("fast")
-				  .set_local_name(_("Fast")));
+				  .set_local_name(_("Fast"))
+				  .set_description(_("When checked, renders quickly but with artifacts"))
+	);
 
 	return ret;
 }
