@@ -7,6 +7,7 @@
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2011 Carlos López
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -65,13 +66,15 @@ SYNFIG_LAYER_SET_CVS_ID(RadialGradient,"$Id$");
 /* === E N T R Y P O I N T ================================================= */
 
 RadialGradient::RadialGradient():
-	Layer_Composite(1.0,Color::BLEND_STRAIGHT),
+	Layer_Composite(1.0,Color::BLEND_COMPOSITE),
 	gradient(Color::black(),Color::white()),
 	center(0,0),
 	radius(0.5),
 	loop(false),
 	zigzag(false)
 {
+	Layer::Vocab voc(get_param_vocab());
+	Layer::fill_static(voc);
 }
 
 bool
@@ -108,10 +111,12 @@ RadialGradient::get_param_vocab()const
 
 	ret.push_back(ParamDesc("gradient")
 		.set_local_name(_("Gradient"))
+		.set_description(_("Gradient to apply"))
 	);
 
 	ret.push_back(ParamDesc("center")
 		.set_local_name(_("Center"))
+		.set_description(_("Center of the gradient"))
 	);
 
 	ret.push_back(ParamDesc("radius")
@@ -123,10 +128,12 @@ RadialGradient::get_param_vocab()const
 
 	ret.push_back(ParamDesc("loop")
 		.set_local_name(_("Loop"))
+		.set_description(_("When checked the gradient is looped"))
 	);
 
 	ret.push_back(ParamDesc("zigzag")
 		.set_local_name(_("ZigZag"))
+		.set_description(_("When checked the gradient is summetrical at the center"))
 	);
 
 	return ret;
