@@ -7,6 +7,7 @@
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007 Chris Moore
+**  Copyright (c) 2011 Carlos López
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -63,11 +64,6 @@ public:
 	virtual String get_local_name()const;
 
 	virtual ValueNode::LooseHandle get_link_vfunc(int i)const;
-	virtual int link_count()const;
-	virtual String link_name(int i)const;
-
-	virtual String link_local_name(int i)const;
-	virtual int get_link_index_from_name(const String &name)const;
 
 	virtual ValueNode* clone(const GUID& deriv_guid=GUID())const;
 
@@ -82,6 +78,7 @@ public:
 	using synfig::LinkableValueNode::set_link_vfunc;
 	static bool check_type(ValueBase::Type type);
 	static ValueNode_Random* create(const ValueBase &x);
+	virtual Vocab get_children_vocab_vfunc()const;
 }; // END of class ValueNode_Random
 
 }; // END of namespace synfig
