@@ -7,6 +7,7 @@
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007, 2008 Chris Moore
+**	Copyright (c) 2011 Carlos López
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -111,6 +112,8 @@ Plant::Plant():
 	sync();
 	size_as_alpha=false;
 	reverse=true;
+	Layer::Vocab voc(get_param_vocab());
+	Layer::fill_static(voc);
 }
 
 void
@@ -278,13 +281,14 @@ Plant::set_param(const String & param, const ValueBase &value)
 		bline=value;
 		bline_loop=value.get_loop();
 		needs_sync_=true;
-
+		set_param_static(param, value.get_static());
 		return true;
 	}
 	if(param=="seed" && value.same_type_as(int()))
 	{
 		random.set_seed(value.get(int()));
 		needs_sync_=true;
+		set_param_static(param, value.get_static());
 		return true;
 	}
 	IMPORT(origin);
@@ -348,7 +352,11 @@ ValueBase
 Plant::get_param(const String& param)const
 {
 	if(param=="seed")
-		return random.get_seed();
+	{
+		ValueBase ret(random.get_seed());
+		ret.set_static(get_param_static(param));
+		return ret;
+	}
 	EXPORT(bline);
 	EXPORT(origin);
 	EXPORT(split_angle);
@@ -388,6 +396,7 @@ Plant::get_param_vocab()const
 
 	ret.push_back(ParamDesc("origin")
 		.set_local_name(_("Origin"))
+		.set_description(_("Offset for the Vertices List"))
 	);
 
 	ret.push_back(ParamDesc("gradient")
