@@ -29,20 +29,16 @@
 /* === H E A D E R S ======================================================= */
 
 
-//#include <cmath>
 #include <math.h>
 #include <cassert>
 #include "gamma.h"
 #include <synfig/string.h>
+# include "angle.h"
 
 #ifdef USE_HALF_TYPE
 #include <OpenEXR/half.h>
 #endif
 
-#ifndef SYNFIG_NO_ANGLE
-# include "angle.h"
-#endif
-
 /* === M A C R O S ========================================================= */
 
 #define use_colorspace_gamma()	App::use_colorspace_gamma
@@ -67,6 +63,8 @@ extern "C" { int _isnan(double x); }
 inline bool isnan(double x) { return x != x; }
 inline bool isnan(float x) { return x != x; }
 #define SYNFIG_ISNAN_FIX 1
+#else
+#define isnan std::isnan
 #endif
 
 namespace synfig {
@@ -386,7 +384,6 @@ public:
 	static Color YUV(const float& y, const float& u, const float& v, const value_type& a=1)
 		{ return Color().set_yuv(y,u,v).set_a(a); }
 
-#ifndef SYNFIG_NO_ANGLE
 	//! Returns the hue of the chromanance
 	/*!	This is the angle of the U and V components.
 	**	\see set_hue() */
@@ -443,7 +440,6 @@ public:
 	static Color YUV(const float& y, const float& s, const Angle& theta, const value_type& a=1)
 		{ return Color().set_yuv(y,s,theta).set_a(a); }
 
-#endif
 
 	//! Clamps a color so that its values are in range. Ignores attempting to visualize negative colors.
 	Color clamped()const;
@@ -498,7 +494,9 @@ public:
 		BLEND_ALPHA_DARKEN=15,		//!< \deprecated If A is more opaque than B, use B
 		BLEND_ALPHA_OVER=19,		//!< \deprecated multiply alphas and then straight blends using the amount
 
-		BLEND_END=22				//!< \internal
+		BLEND_END=22,				//!< \internal
+		BLEND_BY_LAYER=999			//! Used to let the layer decides what Blend Method use by
+									//! default when the layer is created
 	};
 
 	/* Other */
@@ -783,7 +781,7 @@ Color2PixelFormat(const Color &color, const PixelFormat &pf, unsigned char *out,
 	if(FLAGS(pf,PF_ZA|PF_A_START|PF_Z_START))
 	{
 		if(FLAGS(pf,PF_Z_START))
-			*out++/*=(unsigned char)(color.GetZ()*255.0f)*/;
+			out++;
 		if(FLAGS(pf,PF_A_START))
 			*out++=static_cast<unsigned char>(alpha);
 	}
@@ -792,8 +790,7 @@ Color2PixelFormat(const Color &color, const PixelFormat &pf, unsigned char *out,
 		if(FLAGS(pf,PF_A_START))
 			*out++=static_cast<unsigned char>(alpha);
 		if(FLAGS(pf,PF_Z_START))
-			*out++/*=(unsigned char)(color.GetZ()*255.0f)*/;
-
+			out++;
 	}
 
 	if(FLAGS(pf,PF_GRAY))
@@ -817,14 +814,14 @@ Color2PixelFormat(const Color &color, const PixelFormat &pf, unsigned char *out,
 	if(FLAGS(pf,PF_ZA))
 	{
 		if(!FLAGS(pf,PF_Z_START) && FLAGS(pf,PF_Z))
-			out++;//*out++=(unsigned char)(color.GetZ()*255.0f);
+			out++;
 		if(!FLAGS(pf,PF_A_START) && FLAGS(pf,PF_A))
 			*out++=static_cast<unsigned char>(alpha);
 	}
 	else
 	{
 		if(!FLAGS(pf,PF_Z_START) && FLAGS(pf,PF_Z))
-			out++;//*out++=(unsigned char)(color.GetZ()*255.0f);
+			out++;
 		if(!FLAGS(pf,PF_A_START) && FLAGS(pf,PF_A))
 			*out++=static_cast<unsigned char>(alpha);
 	}
@@ -845,7 +842,7 @@ PixelFormat2Color(Color &color, const PixelFormat &pf,const unsigned char *out)
 	if(FLAGS(pf,PF_ZA|PF_A_START|PF_Z_START))
 	{
 		if(FLAGS(pf,PF_Z_START))
-			out++;//color.SetZ((Color::value_type)*out++/255.0f);
+			out++;
 		if(FLAGS(pf,PF_A_START))
 			color.set_a((float)*out++/255);
 	}
@@ -854,7 +851,7 @@ PixelFormat2Color(Color &color, const PixelFormat &pf,const unsigned char *out)
 		if(FLAGS(pf,PF_A_START))
 			color.set_a((float)*out++/255);
 		if(FLAGS(pf,PF_Z_START))
-			out++;//color.SetZ((Color::value_type)*out++/255.0f);
+			out++;
 	}
 
 	if(FLAGS(pf,PF_GRAY))
@@ -878,7 +875,7 @@ PixelFormat2Color(Color &color, const PixelFormat &pf,const unsigned char *out)
 	if(FLAGS(pf,PF_ZA))
 	{
 		if(!FLAGS(pf,PF_Z_START) && FLAGS(pf,PF_Z))
-			out++;//color.SetZ((Color::value_type)*out++/255.0f);
+			out++;
 		if(!FLAGS(pf,PF_A_START) && FLAGS(pf,PF_A))
 			color.set_a((float)*out++/255);
 	}
@@ -887,7 +884,7 @@ PixelFormat2Color(Color &color, const PixelFormat &pf,const unsigned char *out)
 		if(!FLAGS(pf,PF_A_START) && FLAGS(pf,PF_A))
 			color.set_a((float)*out++/255);
 		if(!FLAGS(pf,PF_Z_START) && FLAGS(pf,PF_Z))
-			out++;//color.SetZ((Color::value_type)*out++/255.0f);
+			out++;
 	}
 	return out;
 }
