@@ -1,6 +1,6 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file importer.cpp
-**	\brief writeme
+**	\brief It is the base class for all the importers.
 **
 **	$Id$
 **
@@ -23,8 +23,6 @@
 
 /* === H E A D E R S ======================================================= */
 
-#define SYNFIG_NO_ANGLE
-
 #ifdef USING_PCH
 #	include "pch.h"
 #else
