@@ -7,6 +7,7 @@
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007, 2008 Chris Moore
+**	Copyright (c) 2011 Carlos López
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -92,6 +93,10 @@ Layer_PasteCanvas::Layer_PasteCanvas():
 	children_lock=false;
 	muck_with_time_=true;
 	curr_time=Time::begin();
+	outline_grow=0.0;
+	Layer::Vocab voc(get_param_vocab());
+	Layer::fill_static(voc);
+	set_param_static("children_lock", true);
 }
 
 Layer_PasteCanvas::~Layer_PasteCanvas()
@@ -139,10 +144,12 @@ Layer_PasteCanvas::get_param_vocab()const
 
 	ret.push_back(ParamDesc("time_offset")
 		.set_local_name(_("Time Offset"))
+		.set_description(_("Time Offset to apply to the context"))
 	);
 
 	ret.push_back(ParamDesc("children_lock")
 		.set_local_name(_("Children Lock"))
+		.set_description(_("When checked prevents to select the children using the mouse click"))
 	);
 
 	ret.push_back(ParamDesc("focus")
@@ -153,6 +160,16 @@ Layer_PasteCanvas::get_param_vocab()const
 	//	.set_invisible_duck()
 	);
 
+	ret.push_back(ParamDesc("outline_grow")
+		.set_local_name(_("Outline Grow"))
+		.set_description(_("Exponential value to grow children Outline layers width"))
+	);
+
+	if(canvas && !(canvas->is_inline()))
+	{
+		ret.back().hidden();
+	}
+
 	// optimize_layers() in canvas.cpp makes a new PasteCanvas layer
 	// and copies over the parameters of the old layer.  the
 	// 'curr_time' member wasn't being copied, so I've added it as a
@@ -178,9 +195,9 @@ Layer_PasteCanvas::set_param(const String & param, const ValueBase &value)
 	if(param=="canvas" && value.same_type_as(Canvas::Handle()))
 	{
 		set_sub_canvas(value.get(Canvas::Handle()));
+		set_param_static(param, value.get_static());
 		return true;
 	}
-
 	//! \todo this introduces bug 1844764 if enabled; it was introduced in r954.
 	// http://synfig.org/images/3/3d/Moving-waypoints.sifz is an
 	// example of an animation that has its waypoints displayed
@@ -206,7 +223,7 @@ Layer_PasteCanvas::set_param(const String & param, const ValueBase &value)
 	IMPORT(children_lock);
 	IMPORT(zoom);
 	IMPORT(curr_time);
-
+	IMPORT(outline_grow);
 	return Layer_Composite::set_param(param,value);
 }
 
@@ -274,13 +291,10 @@ Layer_PasteCanvas::update_renddesc()
 void
 Layer_PasteCanvas::on_canvas_set()
 {
-	//synfig::info("before count()=%d",count());
 	if(get_canvas() && canvas && canvas->is_inline() && canvas->parent()!=get_canvas())
 	{
-		//synfig::info("during count()=%d",count());
 		canvas->set_inline(get_canvas());
 	}
-	//synfig::info("after count()=%d",count());
 }
 
 ValueBase
@@ -293,6 +307,7 @@ Layer_PasteCanvas::get_param(const String& param)const
 	EXPORT(time_offset);
 	EXPORT(children_lock);
 	EXPORT(curr_time);
+	EXPORT(outline_grow);
 
 	EXPORT_NAME();
 	EXPORT_VERSION();
@@ -385,7 +400,10 @@ Layer_PasteCanvas::accelerated_render(Context context,Surface *surface,int quali
 	else if (!context.accelerated_render(surface,quality,renddesc,&stageone))
 		return false;
 
-	if(muck_with_time_ && curr_time!=Time::begin() && canvas->get_time()!=curr_time+time_offset)
+	Real grow_value(get_parent_canvas_grow_value());
+	canvas->set_grow_value(outline_grow+grow_value);
+
+	if(muck_with_time_ && curr_time!=Time::begin() /*&& canvas->get_time()!=curr_time+time_offset*/)
 		canvas->set_time(curr_time+time_offset);
 
 	Color::BlendMethod blend_method(get_blend_method());
@@ -568,3 +586,18 @@ void Layer_PasteCanvas::get_times_vfunc(Node::time_set &set) const
 
 	Layer::get_times_vfunc(set);
 }
+
+
+bool
+Layer_PasteCanvas::set_param_static(const String &param, const bool x)
+{
+	return Layer_Composite::set_param_static(param, x);
+}
+
+
+bool
+Layer_PasteCanvas::get_param_static(const String &param) const
+{
+	return Layer_Composite::get_param_static(param);
+}
+
