@@ -7,6 +7,7 @@
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2011 Carlos López
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -67,13 +68,15 @@ SYNFIG_LAYER_SET_CVS_ID(Layer_Polygon,"$Id$");
 /* === M E T H O D S ======================================================= */
 
 Layer_Polygon::Layer_Polygon():
-	Layer_Shape		(1.0,Color::BLEND_COMPOSITE),
-	vector_list		(0)
+	Layer_Shape(1.0,Color::BLEND_COMPOSITE),
+	vector_list(0)
 {
 	vector_list.push_back(Point(0,0.5));
 	vector_list.push_back(Point(-0.333333,0));
 	vector_list.push_back(Point(0.333333,0));
 	sync();
+	Layer::Vocab voc(get_param_vocab());
+	Layer::fill_static(voc);
 }
 
 Layer_Polygon::~Layer_Polygon()
@@ -169,7 +172,8 @@ Layer_Polygon::get_param_vocab()const
 	Layer::Vocab ret(Layer_Shape::get_param_vocab());
 
 	ret.push_back(ParamDesc("vector_list")
-		.set_local_name(_("Vector List"))
+		.set_local_name(_("Vertices List"))
+		.set_description(_("Define the corners of the polygon"))
 		.set_origin("origin")
 	);
 
