@@ -2,7 +2,7 @@
 /*!	\file transform.h
 **	\brief Template Header
 **
-**	$Id: transform.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -49,7 +49,7 @@ public:
 	typedef etl::handle<Transform> Handle;
 
 protected:
-	Transform(const GUID& guid=GUID(0)):guid_(guid) { }
+	Transform(const GUID& guid):guid_(guid) { }
 
 public:
 
