@@ -7,6 +7,7 @@
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007, 2008 Chris Moore
+**  Copyright (c) 2011 Carlos López
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -57,14 +58,15 @@ using namespace etl;
 
 /* === M E T H O D S ======================================================= */
 
-ValueBase::ValueBase():type(TYPE_NIL),data(0),ref_count(0),loop_(0)
+ValueBase::ValueBase():type(TYPE_NIL),data(0),ref_count(0),loop_(0),static_(0)
 {
 }
 
 ValueBase::ValueBase(Type x):
 	type(x),
 	data(0),
-	loop_(0)
+	loop_(0),
+	static_(0)
 {
 	switch(type)
 	{
@@ -77,6 +79,8 @@ ValueBase::ValueBase(Type x):
 	case TYPE_COLOR:		data=static_cast<void*>(new Color());				break;
 	case TYPE_SEGMENT:		data=static_cast<void*>(new Segment());				break;
 	case TYPE_BLINEPOINT:	data=static_cast<void*>(new BLinePoint());			break;
+	case TYPE_WIDTHPOINT:	data=static_cast<void*>(new WidthPoint());			break;
+	case TYPE_DASHITEM:		data=static_cast<void*>(new DashItem());			break;
 	case TYPE_LIST:			data=static_cast<void*>(new list_type());			break;
 	case TYPE_STRING:		data=static_cast<void*>(new String());				break;
 	case TYPE_GRADIENT:		data=static_cast<void*>(new Gradient());			break;
@@ -118,6 +122,8 @@ ValueBase::get_string() const
 	case TYPE_COLOR:		return strprintf("Color (%s)", get(Color()).get_string().c_str());
 	case TYPE_SEGMENT:		return strprintf("Segment ((%f, %f) to (%f, %f))", get(Segment()).p1[0], get(Segment()).p1[1], get(Segment()).p2[0], get(Segment()).p2[1]);
 	case TYPE_BLINEPOINT:	return strprintf("BLinePoint (%s)", get(BLinePoint()).get_vertex()[0], get(BLinePoint()).get_vertex()[1]);
+	case TYPE_WIDTHPOINT:	return strprintf("WidthPoint (%s)", get(WidthPoint()).get_position(), get(WidthPoint()).get_width());
+	case TYPE_DASHITEM:		return strprintf("DashItem (%s)", get(DashItem()).get_offset(), get(DashItem()).get_length());
 
 		// All types after this point require construction/destruction
 
@@ -216,6 +222,7 @@ ValueBase::operator=(const ValueBase& x)
 		ref_count=x.ref_count;
 	}
 	loop_=x.loop_;
+	static_=x.static_;
 	return *this;
 }
 
@@ -235,6 +242,8 @@ ValueBase::clear()
 		case TYPE_COLOR:		delete static_cast<Color*>(data);		break;
 		case TYPE_SEGMENT:		delete static_cast<Segment*>(data);		break;
 		case TYPE_BLINEPOINT:	delete static_cast<BLinePoint*>(data);	break;
+		case TYPE_WIDTHPOINT:	delete static_cast<WidthPoint*>(data);	break;
+		case TYPE_DASHITEM:		delete static_cast<DashItem*>(data);	break;
 		case TYPE_LIST:			delete static_cast<list_type*>(data);	break;
 		case TYPE_CANVAS:
 		{
@@ -264,33 +273,37 @@ ValueBase::type_name(Type id)
 	// don't internationalize these type names - they're using in .sif files
 	switch(id)
 	{
-		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/Types */
+		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/wiki/Dev:Types */
 	case TYPE_BOOL:			return N_("bool");
-		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/Types */
+		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/wiki/Dev:Types */
 	case TYPE_INTEGER:		return N_("integer");
-		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/Types */
+		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/wiki/Dev:Types */
 	case TYPE_ANGLE:		return N_("angle");
-		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/Types */
+		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/wiki/Dev:Types */
 	case TYPE_TIME:			return N_("time");
-		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/Types */
+		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/wiki/Dev:Types */
 	case TYPE_REAL:			return N_("real");
-		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/Types */
+		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/wiki/Dev:Types */
 	case TYPE_VECTOR:		return N_("vector");
-		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/Types */
+		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/wiki/Dev:Types */
 	case TYPE_COLOR:		return N_("color");
-		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/Types */
+		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/wiki/Dev:Types */
 	case TYPE_SEGMENT:		return N_("segment");
-		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/Types */
+		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/wiki/Dev:Types */
 	case TYPE_BLINEPOINT:	return N_("bline_point");
-		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/Types */
+		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/wiki/Dev:Types */
+	case TYPE_WIDTHPOINT:	return N_("width_point");
+		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/wiki/Dev:Types */
+	case TYPE_DASHITEM:		return N_("dash_item");
+		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/wiki/Dev:Types */
 	case TYPE_LIST:			return N_("list");
-		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/Types */
+		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/wiki/Dev:Types */
 	case TYPE_CANVAS:		return N_("canvas");
-		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/Types */
+		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/wiki/Dev:Types */
 	case TYPE_STRING:		return N_("string");
-		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/Types */
+		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/wiki/Dev:Types */
 	case TYPE_GRADIENT:		return N_("gradient");
-		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/Types */
+		/* TRANSLATORS: this is the name of a type -- see http://synfig.org/wiki/Dev:Types */
 	case TYPE_NIL:			return N_("nil");
 	default:
 		break;
@@ -335,6 +348,10 @@ ValueBase::ident_type(const String &str)
 	else if(str=="gradient")	return TYPE_GRADIENT;
 	else if(str=="bline_point" ||
 			str=="blinepoint")	return TYPE_BLINEPOINT;
+	else if(str=="width_point" ||
+			str=="widthpoint")	return TYPE_WIDTHPOINT;
+	else if(str=="dash_item" ||
+			str=="dashitem")	return TYPE_DASHITEM;
 
 	return TYPE_NIL;
 }
@@ -349,21 +366,23 @@ ValueBase::operator==(const ValueBase& rhs)const
 
 	switch(get_type())
 	{
-	case TYPE_TIME:			   return get(Time()).is_equal(rhs.get(Time()));
-	case TYPE_REAL:			   return abs(get(Real())-rhs.get(Real()))<=0.00000000000001;
-	case TYPE_INTEGER:		   return get(int())==rhs.get(int());
-	case TYPE_BOOL:			   return get(bool())==rhs.get(bool());
-	case TYPE_ANGLE:		   return get(Angle())==rhs.get(Angle());
-	case TYPE_VECTOR:		   return get(Vector()).is_equal_to(rhs.get(Vector()));
-	case TYPE_COLOR:		   return get(Color())==rhs.get(Color());
-	case TYPE_STRING:		   return get(String())==rhs.get(String());
-	case TYPE_CANVAS:		   return get(Canvas::LooseHandle())==rhs.get(Canvas::LooseHandle());
-	case TYPE_LIST:			   return get_list()==rhs.get_list();
-	case TYPE_SEGMENT:		// return get(Segment())==rhs.get(Segment());
-	case TYPE_GRADIENT:		// return get(Gradient())==rhs.get(Gradient());
-	case TYPE_BLINEPOINT:	// return get(BLinePoint())==rhs.get(BLinePoint());
+	case TYPE_TIME:            return get(Time()).is_equal(rhs.get(Time()));
+	case TYPE_REAL:            return abs(get(Real())-rhs.get(Real()))<=0.00000000000001;
+	case TYPE_INTEGER:         return get(int())==rhs.get(int());
+	case TYPE_BOOL:            return get(bool())==rhs.get(bool());
+	case TYPE_ANGLE:           return get(Angle())==rhs.get(Angle());
+	case TYPE_VECTOR:          return get(Vector()).is_equal_to(rhs.get(Vector()));
+	case TYPE_COLOR:           return get(Color())==rhs.get(Color());
+	case TYPE_STRING:          return get(String())==rhs.get(String());
+	case TYPE_CANVAS:          return get(Canvas::LooseHandle())==rhs.get(Canvas::LooseHandle());
+	case TYPE_LIST:            return get_list()==rhs.get_list();
+	case TYPE_WIDTHPOINT:      return get(WidthPoint())==rhs.get(WidthPoint());
+	case TYPE_DASHITEM:        return get(DashItem())==rhs.get(DashItem());
+	case TYPE_SEGMENT:      // return get(Segment())==rhs.get(Segment());
+	case TYPE_GRADIENT:     // return get(Gradient())==rhs.get(Gradient());
+	case TYPE_BLINEPOINT:   // return get(BLinePoint())==rhs.get(BLinePoint());
 	case TYPE_NIL:
-	default:				   return false;
+	default:                   return false;
 	}
 	return false;
 }
