@@ -7,7 +7,7 @@
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007, 2008 Chris Moore
-**  Copyright (c) 2008 Carlos López
+**  Copyright (c) 2008, 2011 Carlos López
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -24,10 +24,6 @@
 
 /* === H E A D E R S ======================================================= */
 
-#define SYNFIG_NO_ANGLE
-
-//#define HAS_HASH_MAP 1
-
 #ifdef USING_PCH
 #	include "pch.h"
 #else
@@ -38,7 +34,6 @@
 #include "valuenode.h"
 #include "general.h"
 #include "canvas.h"
-#include "paramdesc.h"
 #include "releases.h"
 
 #include "valuenode_const.h"
@@ -61,6 +56,8 @@
 #include "valuenode_timedswap.h"
 #include "valuenode_twotone.h"
 #include "valuenode_bline.h"
+#include "valuenode_wplist.h"
+#include "valuenode_dilist.h"
 #include "valuenode_dynamiclist.h"
 #include "valuenode_radialcomposite.h"
 #include "valuenode_gradientrotate.h"
@@ -192,6 +189,9 @@ ValueNode::subsys_init()
 	ADD_VALUENODE(ValueNode_And,		      "and",			  _("And"),				 RELEASE_VERSION_0_62_00); // SVN r2364
 	ADD_VALUENODE(ValueNode_Or,		          "or",			  _("Or"),					 RELEASE_VERSION_0_62_00); // SVN r2364
 
+	ADD_VALUENODE(ValueNode_WPList,           "wplist",           _("WPList"),           RELEASE_VERSION_0_63_00);
+	ADD_VALUENODE(ValueNode_DIList,           "dilist",           _("DIList"),           RELEASE_VERSION_0_63_01);
+
 #undef ADD_VALUENODE
 #undef ADD_VALUENODE2
 
@@ -202,35 +202,6 @@ bool
 ValueNode::subsys_stop()
 {
 	delete book_;
-/*	if(global_value_node_map.size() || value_node_count)
-	{
-		if(value_node_count)
-			synfig::error("%d ValueNodes haven't been destroyed yet!",value_node_count);
-
-		if(global_value_node_map.size()!=value_node_count)
-			synfig::error("value node count mismatch! map.size()!=value_node_count (%d!=%d)",global_value_node_map.size(),value_node_count);
-
-		GlobalValueNodeMap::iterator iter;
-		for(iter=global_value_node_map.begin();iter!=global_value_node_map.end();++iter)
-		{
-			if(!iter->second->is_exported())
-				synfig::info(_("%s: count:%d name:%s type:%s"),
-					iter->first.get_string().c_str(),
-					iter->second->count(),
-					iter->second->get_name().c_str(),
-					ValueBase::type_local_name(iter->second->get_type()).c_str()
-				);
-			else
-				synfig::info(_("%s: id:%s count:%d name:%s type:%s"),
-					iter->first.get_string().c_str(),
-					iter->second->get_id().c_str(),
-					iter->second->count(),
-					iter->second->get_name().c_str(),
-					ValueBase::type_local_name(iter->second->get_type()).c_str()
-				);
-		}
-	}
-*/
 	return true;
 }
 
@@ -339,7 +310,7 @@ ValueNode::on_changed()
 	if(parent_canvas)
 		do						// signal to all the ancestor canvases
 			parent_canvas->signal_value_node_changed()(this);
-		while (parent_canvas = parent_canvas->parent());
+		while ( (parent_canvas = parent_canvas->parent()) );
 	else if(get_root_canvas())
 		get_root_canvas()->signal_value_node_changed()(this);
 
@@ -702,3 +673,58 @@ LinkableValueNode::get_description(int index, bool show_exported_name)const
 
 	return description;
 }
+
+String
+LinkableValueNode::get_description(bool show_exported_name)const
+{
+	return get_description(-1, show_exported_name);
+}
+
+String
+LinkableValueNode::link_name(int i)const
+{
+	Vocab vocab(get_children_vocab());
+	Vocab::iterator iter(vocab.begin());
+	int j=0;
+	for(; iter!=vocab.end() && j<i; iter++, j++);
+	return iter!=vocab.end()?iter->get_name():String();
+}
+
+String
+LinkableValueNode::link_local_name(int i)const
+{
+	Vocab vocab(get_children_vocab());
+	Vocab::iterator iter(vocab.begin());
+	int j=0;
+	for(; iter!=vocab.end() && j<i; iter++, j++);
+	return iter!=vocab.end()?iter->get_local_name():String();
+}
+
+int
+LinkableValueNode::get_link_index_from_name(const String &name)const
+{
+	Vocab vocab(get_children_vocab());
+	Vocab::iterator iter(vocab.begin());
+	int j=0;
+	for(; iter!=vocab.end(); iter++, j++)
+		if(iter->get_name()==name) return j;
+	throw Exception::BadLinkName(name);
+}
+
+int
+LinkableValueNode::link_count()const
+{
+	return get_children_vocab().size();
+}
+
+LinkableValueNode::Vocab
+LinkableValueNode::get_children_vocab()const
+{
+	return get_children_vocab_vfunc();
+}
+
+void
+LinkableValueNode::set_children_vocab(const Vocab &newvocab)
+{
+	children_vocab.assign(newvocab.begin(),newvocab.end());
+}
