@@ -7,6 +7,7 @@
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007, 2008 Chris Moore
+**  Copyright (c) 2011 Carlos López
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -58,6 +59,8 @@ using namespace synfig;
 ValueNode_BLineCalcTangent::ValueNode_BLineCalcTangent(const ValueBase::Type &x):
 	LinkableValueNode(x)
 {
+	Vocab ret(get_children_vocab());
+	set_children_vocab(ret);
 	if(x!=ValueBase::TYPE_ANGLE && x!=ValueBase::TYPE_REAL && x!=ValueBase::TYPE_VECTOR)
 		throw Exception::BadType(ValueBase::type_local_name(x));
 
@@ -68,6 +71,7 @@ ValueNode_BLineCalcTangent::ValueNode_BLineCalcTangent(const ValueBase::Type &x)
 	set_link("offset",ValueNode_Const::create(Angle::deg(0)));
 	set_link("scale",ValueNode_Const::create(Real(1.0)));
 	set_link("fixed_length",ValueNode_Const::create(bool(false)));
+	set_link("homogeneous",ValueNode_Const::create(bool(true)));
 }
 
 LinkableValueNode*
@@ -98,9 +102,14 @@ ValueNode_BLineCalcTangent::operator()(Time t, Real amount)const
 	const bool looped(bline_value_node->get_loop());
 	int size = bline.size(), from_vertex;
 	bool loop((*loop_)(t).get(bool()));
+	bool homogeneous((*homogeneous_)(t).get(bool()));
 	Angle offset((*offset_)(t).get(Angle()));
 	Real scale((*scale_)(t).get(Real()));
 	bool fixed_length((*fixed_length_)(t).get(bool()));
+	if(homogeneous)
+	{
+		amount=hom_to_std(bline, amount, loop, looped);
+	}
 	BLinePoint blinepoint0, blinepoint1;
 
 	if (!looped) size--;
@@ -188,6 +197,7 @@ ValueNode_BLineCalcTangent::set_link_vfunc(int i,ValueNode::Handle value)
 	case 3: CHECK_TYPE_AND_SET_VALUE(offset_,		ValueBase::TYPE_ANGLE);
 	case 4: CHECK_TYPE_AND_SET_VALUE(scale_,		ValueBase::TYPE_REAL);
 	case 5: CHECK_TYPE_AND_SET_VALUE(fixed_length_,	ValueBase::TYPE_BOOL);
+	case 6: CHECK_TYPE_AND_SET_VALUE(homogeneous_,	ValueBase::TYPE_BOOL);
 	}
 	return false;
 }
@@ -205,63 +215,12 @@ ValueNode_BLineCalcTangent::get_link_vfunc(int i)const
 		case 3: return offset_;
 		case 4: return scale_;
 		case 5: return fixed_length_;
+		case 6: return homogeneous_;
 	}
 
 	return 0;
 }
 
-int
-ValueNode_BLineCalcTangent::link_count()const
-{
-	return 6;
-}
-
-String
-ValueNode_BLineCalcTangent::link_name(int i)const
-{
-	assert(i>=0 && i<link_count());
-
-	switch(i)
-	{
-		case 0: return "bline";
-		case 1: return "loop";
-		case 2: return "amount";
-		case 3: return "offset";
-		case 4: return "scale";
-		case 5: return "fixed_length";
-	}
-	return String();
-}
-
-String
-ValueNode_BLineCalcTangent::link_local_name(int i)const
-{
-	assert(i>=0 && i<link_count());
-
-	switch(i)
-	{
-		case 0: return _("BLine");
-		case 1: return _("Loop");
-		case 2: return _("Amount");
-		case 3: return _("Offset");
-		case 4: return _("Scale");
-		case 5: return _("Fixed Length");
-	}
-	return String();
-}
-
-int
-ValueNode_BLineCalcTangent::get_link_index_from_name(const String &name)const
-{
-	if (name=="bline")		  return 0;
-	if (name=="loop")		  return 1;
-	if (name=="amount")		  return 2;
-	if (name=="offset")		  return 3;
-	if (name=="scale")		  return 4;
-	if (name=="fixed_length") return 5;
-	throw Exception::BadLinkName(name);
-}
-
 bool
 ValueNode_BLineCalcTangent::check_type(ValueBase::Type type)
 {
@@ -269,3 +228,48 @@ ValueNode_BLineCalcTangent::check_type(ValueBase::Type type)
 			type==ValueBase::TYPE_REAL  ||
 			type==ValueBase::TYPE_VECTOR);
 }
+
+LinkableValueNode::Vocab
+ValueNode_BLineCalcTangent::get_children_vocab_vfunc()const
+{
+	if(children_vocab.size())
+		return children_vocab;
+
+	LinkableValueNode::Vocab ret;
+
+	ret.push_back(ParamDesc(ValueBase(),"bline")
+		.set_local_name(_("BLine"))
+		.set_description(_("The BLine where the tangent is linked to"))
+	);
+
+	ret.push_back(ParamDesc(ValueBase(),"loop")
+		.set_local_name(_("Loop"))
+		.set_description(_("When checked, the amount would loop"))
+	);
+
+	ret.push_back(ParamDesc(ValueBase(),"amount")
+		.set_local_name(_("Amount"))
+		.set_description(_("The position of the linked tangent on the BLine (0,1]"))
+	);
+
+	ret.push_back(ParamDesc(ValueBase(),"offset")
+		.set_local_name(_("Offset"))
+		.set_description(_("Angle offset of the tangent"))
+	);
+
+	ret.push_back(ParamDesc(ValueBase(),"scale")
+		.set_local_name(_("Scale"))
+		.set_description(_("Scale of the tangent"))
+	);
+
+	ret.push_back(ParamDesc(ValueBase(),"fixed_length")
+		.set_local_name(_("Fixed Length"))
+		.set_description(_("When checked, the tangent's length is fixed"))
+	);
+
+	ret.push_back(ParamDesc(ValueBase(),"homogeneous")
+		.set_local_name(_("Homogeneous"))
+		.set_description(_("When checked, the tangent is BLine length based"))
+	);
+	return ret;
+}
