@@ -50,7 +50,6 @@ using namespace synfig;
 
 ValueNode_Const::ValueNode_Const()
 {
-	DCAST_HACK_ENABLE();
 }
 
 
@@ -58,7 +57,6 @@ ValueNode_Const::ValueNode_Const(const ValueBase &x):
 	ValueNode	(x.get_type()),
 	value		(x)
 {
-	DCAST_HACK_ENABLE();
 }
 
 
@@ -120,13 +118,13 @@ ValueNode_Const::set_value(const ValueBase &data)
 String
 ValueNode_Const::get_name()const
 {
-	return "constant";
+	return get_static()?"static":"constant";
 }
 
 String
 ValueNode_Const::get_local_name()const
 {
-	return _("Constant");
+	return get_static()?_("Static"):_("Constant");
 }
 
 void ValueNode_Const::get_times_vfunc(Node::time_set &/*set*/) const
