@@ -56,7 +56,8 @@ public:
 	ValueBase &get_value();
 	void set_value(const ValueBase &data);
 
-
+	bool get_static()const {return get_value().get_static();}
+	void set_static(bool x) { get_value().set_static(x); }
 	virtual String get_name()const;
 	virtual String get_local_name()const;
 
