@@ -7,6 +7,7 @@
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2008 Chris Moore
+**  Copyright (c) 2011 Carlos López
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -137,62 +138,101 @@ ValueNode_DynamicList::ListEntry
 ValueNode_DynamicList::create_list_entry(int index, Time time, Real origin)
 {
 	ValueNode_DynamicList::ListEntry ret;
-
-
+	int c(link_count());
 	synfig::ValueBase prev,next;
 
-	index=index%link_count();
+	if(c)
+		index=index%c;
+	else
+		index=0;
 
 	assert(index>=0);
 
 	ret.index=index;
 	ret.set_parent_value_node(this);
 
-	next=(*list[index].value_node)(time);
-
-	if(index!=0)
-		prev=(*list[index-1].value_node)(time);
-	else
+	if(c)
 	{
-		if(get_loop())
-			prev=(*list[link_count()-1].value_node)(time);
+		next=(*list[index].value_node)(time);
+
+		if(index!=0)
+			prev=(*list[index-1].value_node)(time);
 		else
 		{
-			prev=next;
+			if(get_loop())
+			prev=(*list[link_count()-1].value_node)(time);
+			else
+			{
+				prev=next;
+			}
 		}
 	}
 
-
 	switch(get_contained_type())
 	{
 	case ValueBase::TYPE_VECTOR:
 	{
-		Vector a(prev.get(Vector())), b(next.get(Vector()));
-		ret.value_node=ValueNode_Const::create((b-a)*origin+a);
+		if(c)
+		{
+			Vector a(prev.get(Vector())), b(next.get(Vector()));
+			ret.value_node=ValueNode_Const::create((b-a)*origin+a);
+		}
+		else
+		{
+			ret.value_node=ValueNode_Const::create(Vector());
+		}
 		break;
 	}
 	case ValueBase::TYPE_REAL:
 	{
-		Real a(prev.get(Real())), b(next.get(Real()));
-		ret.value_node=ValueNode_Const::create((b-a)*origin+a);
+		if(c)
+		{
+			Real a(prev.get(Real())), b(next.get(Real()));
+			ret.value_node=ValueNode_Const::create((b-a)*origin+a);
+		}
+		else
+		{
+			ret.value_node=ValueNode_Const::create(Real());
+		}
 		break;
 	}
 	case ValueBase::TYPE_COLOR:
 	{
-		Color a(prev.get(Color())), b(next.get(Color()));
-		ret.value_node=ValueNode_Composite::create((b-a)*origin+a);
+		if(c)
+		{
+			Color a(prev.get(Color())), b(next.get(Color()));
+			ret.value_node=ValueNode_Composite::create((b-a)*origin+a);
+		}
+		else
+		{
+			ret.value_node=ValueNode_Const::create(Color());
+		}
 		break;
 	}
 	case ValueBase::TYPE_ANGLE:
 	{
-		Angle a(prev.get(Angle())), b(next.get(Angle()));
-		ret.value_node=ValueNode_Const::create((b-a)*origin+a);
+		if(c)
+		{
+			Angle a(prev.get(Angle())), b(next.get(Angle()));
+			ret.value_node=ValueNode_Const::create((b-a)*origin+a);
+		}
+		else
+		{
+			ret.value_node=ValueNode_Const::create(Angle());
+		}
 		break;
 	}
 	case ValueBase::TYPE_TIME:
 	{
-		Time a(prev.get(Time())), b(next.get(Time()));
-		ret.value_node=ValueNode_Const::create((b-a)*origin+a);
+		if(c)
+		{
+			Time a(prev.get(Time())), b(next.get(Time()));
+			ret.value_node=ValueNode_Const::create((b-a)*origin+a);
+		}
+		else
+		{
+			ret.value_node=ValueNode_Const::create(Time());
+		}
 		break;
 	}
 	default:
@@ -550,7 +590,6 @@ ValueNode_DynamicList::ValueNode_DynamicList(ValueBase::Type container_type):
 	container_type	(container_type),
 	loop_(false)
 {
-	DCAST_HACK_ENABLE();
 }
 
 ValueNode_DynamicList::Handle
@@ -907,3 +946,17 @@ ValueNode_DynamicList::insert_time(const Time& location, const Time& delta)
 	}
 	changed();
 }
+
+LinkableValueNode::Vocab
+ValueNode_DynamicList::get_children_vocab_vfunc()const
+{
+	LinkableValueNode::Vocab ret;
+	for(unsigned int i=0; i<list.size();i++)
+	{
+		ret.push_back(ParamDesc(ValueBase(),strprintf("item%04d",i))
+			.set_local_name(etl::strprintf(_("Item %03d"),i+1))
+		);
+	}
+
+	return ret;
+}
