@@ -6,6 +6,7 @@
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**  Copyright (c) 2011 Carlos López
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -47,24 +48,14 @@ public:
 	typedef etl::handle<ValueNode_SegCalcVertex> Handle;
 	typedef etl::handle<const ValueNode_SegCalcVertex> ConstHandle;
 
-//	static Handle create(const ValueBase::Type &x=ValueBase::TYPE_VECTOR);
-
-
 	virtual ValueBase operator()(Time t)const;
 
 	virtual ~ValueNode_SegCalcVertex();
 
 	virtual String get_name()const;
 	virtual String get_local_name()const;
-//	static bool check_type(const ValueBase::Type &type);
-
 
 	virtual ValueNode::LooseHandle get_link_vfunc(int i)const;
-	virtual int link_count()const;
-	virtual String link_name(int i)const;
-
-	virtual String link_local_name(int i)const;
-	virtual int get_link_index_from_name(const String &name)const;
 
 protected:
 	LinkableValueNode* create_new()const;
@@ -75,6 +66,7 @@ public:
 	using synfig::LinkableValueNode::set_link_vfunc;
 	static bool check_type(ValueBase::Type type);
 	static ValueNode_SegCalcVertex* create(const ValueBase &x=ValueBase::TYPE_VECTOR);
+	virtual Vocab get_children_vocab_vfunc()const;
 }; // END of class ValueNode_SegCalcVertex
 
 }; // END of namespace synfig
